pub type WsStream = SplitStream<WebSocket>;Expand description
Convenient type alias for the Stream half of a tungstenite WebSocket.
Aliased Type
pub struct WsStream(/* private fields */);pub type WsStream = SplitStream<WebSocket>;Convenient type alias for the Stream half of a tungstenite WebSocket.
pub struct WsStream(/* private fields */);